# YaDraw

YaDraw is a super-simple graphical interface built on top of pygame.
The key use case is when you have a program which performs some calculations, 
and you want to add super-simple visualization to it. YaDraw supports basic primitives and shapes. 
YaDraw can also operate with raw pygame methods (see test cases).
[Github repo](https://github.com/EmixD/yadraw).